@@ -150,7 +150,7 @@ def player_search(db, full_name, team=None, position=None,
             qposition = cursor.mogrify('position = %s', (position,))
 
         fuzzy_filled = cursor.mogrify(fuzzy, (full_name,))
-        columns = types.Player._sql_select_fields(types.Player._sql_fields());
+        columns = types.Player._sql_select_fields(types.Player._sql_fields())
         columns.append('%s AS distance' % fuzzy_filled)
         q = q.format(
             columns=', '.join(columns),
@@ -583,10 +583,11 @@ class Query (Condition):
         [open an issue](https://github.com/BurntSushi/nfldb/issues/new)
         if you can think of other special fields to add.
         """
-        _append_conds(self._default_cond, types.Game, kw)
         if 'team' in kw:
-            ors = {'home_team': kw['team'], 'away_team': kw['team']}
+            team = kw.pop('team')
+            ors = {'home_team': team, 'away_team': team}
             self.andalso(Query(self._db, orelse=True).game(**ors))
+        _append_conds(self._default_cond, types.Game, kw)
         return self
 
     def drive(self, **kw):
@@ -698,7 +699,7 @@ class Query (Condition):
         _append_conds(self._agg_default_cond, types.PlayPlayer, kw)
         return self
 
-    def _make_join_query(self, cursor, entity, only_prim=False):
+    def _make_join_query(self, cursor, entity, only_prim=False, sorter=None):
         entities = self._entities()
         entities.discard(entity)
 
@@ -715,12 +716,14 @@ class Query (Condition):
         fields = None
         if only_prim:
             fields = entity._sql_tables['primary']
+        if sorter is None:
+            sorter = self._sorter
         args = {
             'select_from': entity._sql_select_from(fields=fields),
             'joins': entity._sql_join_all(entities),
             'where': sql.ands(self._sql_where(cursor)),
             'groupby': '',
-            'sortby': self._sorter.sql(entity),
+            'sortby': sorter.sql(entity),
         }
 
         # We need a GROUP BY if we're joining with a table that has more
@@ -785,11 +788,27 @@ class Query (Condition):
 
         self._assert_no_aggregate()
 
+        # This is pretty terrifying.
+        # Apparently PostgreSQL can change the order of rows returned
+        # depending on the columns selected. So e.g., if you sort by `down`
+        # and limit to 20 results, you might get a different 20 plays if
+        # you change which columns you're selecting.
+        # This is pertinent here because if we're filling plays with player
+        # statistics, then we are assuming that this order never changes.
+        # To make the ordering consistent, we add the play's primary key to
+        # the existing sort criteria, which guarantees that the sort will
+        # always be the same.
+        # (We are careful not to override the user specified
+        # `self._sort_exprs`.
+        consistent = [(c, 'asc') for c in ['gsis_id', 'drive_id', 'play_id']]
+        sorter = Sorter(self._sort_exprs, self._limit)
+        sorter.exprs += consistent
+
         if not fill:
             results = []
             with Tx(self._db, factory=tuple_cursor) as cursor:
                 init = types.Play._from_tuple
-                q = self._make_join_query(cursor, types.Play)
+                q = self._make_join_query(cursor, types.Play, sorter=sorter)
                 cursor.execute(q)
                 for row in cursor.fetchall():
                     results.append(init(self._db, row))
@@ -798,7 +817,7 @@ class Query (Condition):
             plays = OrderedDict()
             with Tx(self._db, factory=tuple_cursor) as cursor:
                 init_play = types.Play._from_tuple
-                q = self._make_join_query(cursor, types.Play)
+                q = self._make_join_query(cursor, types.Play, sorter=sorter)
                 cursor.execute(q)
                 for row in cursor.fetchall():
                     play = init_play(self._db, row)
@@ -808,7 +827,8 @@ class Query (Condition):
                 # Run the above query *again* as a subquery.
                 # This time, only fetch the primary key, and use that to
                 # fetch all the `play_player` records in one swoop.
-                ids = self._make_join_query(cursor, types.Play, only_prim=True)
+                ids = self._make_join_query(cursor, types.Play,
+                                            only_prim=True, sorter=sorter)
                 select_from = types.PlayPlayer._sql_select_from(
                     aliases={'play_player': 'pp'})
                 q = '''
@@ -874,23 +894,6 @@ class Query (Condition):
         If any sorting criteria is specified, it is applied to the
         aggregate *player* values only.
         """
-        # The central approach here is to buck the trend of the other
-        # `as_*` methods and do a JOIN to perform our search.
-        # We do this because `IN` expressions are limited in the number
-        # of sub-expressions they can contain, and since we can't do our
-        # usual post-filtering with Python (since it's an aggregate),
-        # we must resort to doing all the filtering in PostgreSQL.
-        #
-        # The only other option I can think of is to load the identifiers
-        # into a temporary table and use a subquery with an `IN` expression,
-        # which I'm told isn't subject to the normal limitations. However,
-        # I'm not sure if it's economical to run a query against a big
-        # table with so many `OR` expressions. More convincingly, the
-        # approach I've used below seems to be *fast enough*.
-        #
-        # Ideas and experiments are welcome. Using a join seems like the
-        # most sensible approach at the moment (and it's simple!), but I'd like
-        # to experiment with other ideas in the future.
         joins = ''
         results = []
 
@@ -901,7 +904,7 @@ class Query (Condition):
                 joins += types.PlayPlayer._sql_join_to_all(ent)
 
             sum_fields = types._player_categories.keys() \
-                         + types.PlayPlayer._sql_tables['derived']
+                + types.PlayPlayer._sql_tables['derived']
             select_sum_fields = types.PlayPlayer._sql_select_fields(
                 sum_fields, wrap=lambda f: 'SUM(%s)' % f)
             where = self._sql_where(cur)
